pub struct AffineRemlProfile<'a> { /* private fields */ }Expand description
Spectral REML/profile score with affine diagonal modes
h_i(lambda) = g_i + lambda s_i.
projected_rhs_squared is RESPONSE-MAJOR: entry (d, i) is stored at
d * n_modes + i. The score is
-1/2 { D [logdet_constant + sum log h_i - rank log(lambda)] + residual_dof * sum_d log(R_d / residual_dof) },
where R_d = response_energy[d] - sum_i q[d,i] / h_i.
Implementations
Sourceimpl<'a> AffineRemlProfile<'a>
impl<'a> AffineRemlProfile<'a>
pub fn new( gram_modes: &'a [f64], penalty_modes: &'a [f64], projected_rhs_squared: &'a [f64], response_energy: &'a [f64], residual_dof: f64, determinant_rank: usize, logdet_constant: f64, ) -> Result<Self, AffineRemlError>
pub fn num_modes(&self) -> usize
pub fn num_responses(&self) -> usize
Sourcepub fn evaluate(&self, log_lambda: f64) -> Result<ScoreJet, AffineRemlError>
pub fn evaluate(&self, log_lambda: f64) -> Result<ScoreJet, AffineRemlError>
Exact score value, first derivative, and second derivative in
log(lambda).
Sourcepub fn enclose(
&self,
lo: f64,
hi: f64,
) -> Result<DerivativeEnclosure, AffineRemlError>
pub fn enclose( &self, lo: f64, hi: f64, ) -> Result<DerivativeEnclosure, AffineRemlError>
Outward enclosure of the first two score derivatives on a bounded log-lambda interval.
pub fn maximize( &self, lo: f64, hi: f64, resolution: f64, ) -> Result<ScoreSearchResult, ScoreSearchError<AffineRemlError>>