StationaryPoint

Struct StationaryPoint 

pub struct StationaryPoint {
    pub sample: ScoreSample,
    pub bracket: ClosedInterval,
}
One stationary point together with the final bracket that certifies its location. The bracket width is no larger than the requested resolution, unless the point was represented exactly (a zero-width bracket).

Fields

sample: ScoreSamplebracket: ClosedInterval