ScoreSearchError

Enum ScoreSearchError 

pub enum ScoreSearchError<E> {
    InvalidDomain {
        lo: f64,
        hi: f64,
    },
    InvalidResolution {
        resolution: f64,
    },
    PointEvaluation {
        x: f64,
        source: E,
    },
    EnclosureEvaluation {
        lo: f64,
        hi: f64,
        source: E,
    },
    NonFiniteSample {
        sample: ScoreSample,
    },
    InvalidEnclosure {
        lo: f64,
        hi: f64,
        enclosure: DerivativeEnclosure,
    },
    EnclosureMissesEndpoint {
        lo: f64,
        hi: f64,
        endpoint: ScoreSample,
        enclosure: DerivativeEnclosure,
    },
    Unresolved {
        lo: f64,
        hi: f64,
        requested_resolution: f64,
        enclosure: DerivativeEnclosure,
    },
}
Failure of the generic certified search.

Variants



InvalidDomain

Fields

lo: f64
hi: f64


InvalidResolution

Fields

resolution: f64


PointEvaluation

Fields

source: E


EnclosureEvaluation

Fields

lo: f64
hi: f64
source: E


NonFiniteSample

Fields



InvalidEnclosure

Fields

lo: f64
hi: f64


EnclosureMissesEndpoint

Fields

lo: f64
hi: f64
endpoint: ScoreSample


Unresolved

The enclosure still admits both a stationary point and a curvature zero, so uniqueness could not be proved before the requested or floating-point resolution floor.

Fields

lo: f64
hi: f64
requested_resolution: f64