pub struct StationaryPoint {
pub sample: ScoreSample,
pub bracket: ClosedInterval,
}Expand description
One stationary point together with the final bracket that certifies its location. The bracket width is no larger than the requested resolution, unless the point was represented exactly (a zero-width bracket).
Fields
sample: ScoreSamplebracket: ClosedIntervalTrait Implementations
Sourceimpl Clone for StationaryPoint
impl Clone for StationaryPoint
Sourcefn clone(&self) -> StationaryPoint
fn clone(&self) -> StationaryPoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StationaryPoint
Sourceimpl Debug for StationaryPoint
impl Debug for StationaryPoint
Sourceimpl PartialEq for StationaryPoint
impl PartialEq for StationaryPoint
impl StructuralPartialEq for StationaryPoint